==> haskell-vector-0.13.2.0-227-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector
version:              0.13.2.0
visibility:           public
id:                   vector-0.13.2.0-7tdWOYp2iIT6MWN6R7TRos
key:                  vector-0.13.2.0-7tdWOYp2iIT6MWN6R7TRos
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  c3a7a0b1ccd0e69d99e67591bc8511d7
exposed:              True
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Strict Data.Vector.Strict.Mutable Data.Vector.Unboxed
    Data.Vector.Unboxed.Base Data.Vector.Unboxed.Mutable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-7tdWOYp2iIT6MWN6R7TRos
include-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0/include
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    primitive-0.9.1.0-IzoEy6gcvXy7FAbkwCq547
    vector-stream-0.1.0.1-F03bfhC0HhqL26lQDSs4vb

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-vector-z-benchmarks-O2
version:              0.13.2.0
package-name:         vector
lib-name:             benchmarks-O2
visibility:           public
id:                   vector-0.13.2.0-9YXOL3ltF4A71KOMElNE0-benchmarks-O2
key:                  vector-0.13.2.0-9YXOL3ltF4A71KOMElNE0-benchmarks-O2
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  d4102b7dde97ad83518f03105e4a672a
exposed-modules:
    Bench.Vector.Algo.AwShCC Bench.Vector.Algo.FindIndexR
    Bench.Vector.Algo.HybCC Bench.Vector.Algo.Leaffix
    Bench.Vector.Algo.ListRank Bench.Vector.Algo.MutableSet
    Bench.Vector.Algo.NextPermutation Bench.Vector.Algo.Quickhull
    Bench.Vector.Algo.Rootfix Bench.Vector.Algo.Spectral
    Bench.Vector.Algo.Tridiag Bench.Vector.Tasty
    Bench.Vector.TestData.Graph Bench.Vector.TestData.ParenTree

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-9YXOL3ltF4A71KOMElNE0-benchmarks-O2
depends:
    base-4.17.2.1 random-1.2.1.3-5Vfv7B7ZdGT6rasffmKWRk
    tasty-1.5-39oVeMckyKI19jkIsiUDu6
    vector-0.13.2.0-7tdWOYp2iIT6MWN6R7TRos

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-0.13.2.0-228-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector
version:              0.13.2.0
visibility:           public
id:                   vector-0.13.2.0-KqylBOQs17JGUC9KjqRYlR
key:                  vector-0.13.2.0-KqylBOQs17JGUC9KjqRYlR
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  92471b14e0ed2226f841cb567e654f25
exposed:              True
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Strict Data.Vector.Strict.Mutable Data.Vector.Unboxed
    Data.Vector.Unboxed.Base Data.Vector.Unboxed.Mutable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-KqylBOQs17JGUC9KjqRYlR
include-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0/include
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    primitive-0.9.1.0-9RF5UPzNfxF3rXGzmAaAQ3
    vector-stream-0.1.0.1-F03bfhC0HhqL26lQDSs4vb

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-vector-z-benchmarks-O2
version:              0.13.2.0
package-name:         vector
lib-name:             benchmarks-O2
visibility:           public
id:                   vector-0.13.2.0-FLKhnKxB42lHVyUZheZwz0-benchmarks-O2
key:                  vector-0.13.2.0-FLKhnKxB42lHVyUZheZwz0-benchmarks-O2
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  c6c240f70949ebe9f2b480b630df39cd
exposed-modules:
    Bench.Vector.Algo.AwShCC Bench.Vector.Algo.FindIndexR
    Bench.Vector.Algo.HybCC Bench.Vector.Algo.Leaffix
    Bench.Vector.Algo.ListRank Bench.Vector.Algo.MutableSet
    Bench.Vector.Algo.NextPermutation Bench.Vector.Algo.Quickhull
    Bench.Vector.Algo.Rootfix Bench.Vector.Algo.Spectral
    Bench.Vector.Algo.Tridiag Bench.Vector.Tasty
    Bench.Vector.TestData.Graph Bench.Vector.TestData.ParenTree

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-FLKhnKxB42lHVyUZheZwz0-benchmarks-O2
depends:
    base-4.17.2.1 random-1.2.1.3-5Vfv7B7ZdGT6rasffmKWRk
    tasty-1.5-39oVeMckyKI19jkIsiUDu6
    vector-0.13.2.0-KqylBOQs17JGUC9KjqRYlR

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
